@@ -30,7 +30,7 @@ writeSummaryRTMPT <- function(x, keep, ...) {
   Ntau_p <- sum(is.na(x$specs$model$params$taus[2,]))
   Ntaus <- Ntau_m + Ntau_p
   Nparams <- Nprobs+Ntaus
-  Nresps <- length(unique(x$specs$model$responses$RESP))
+  Nresps <- length(unique(x$specs$model$responses$MAP))
   Ngroups <- x$specs$n.groups
   Nsubj <- x$specs$n.subj
   subj_exist <- exists("subj", x$specs$transformation)
@@ -335,14 +335,128 @@ print.rtmpt_fit <- function(x, ...) {
     index <- which(!is.na(x$specs$model$params$probs))
     index_orig <- index
     if (x$specs$n.groups>1) for (i in 1:(x$specs$n.groups-1)) {index <- c(index, index+length(rowNms))}
-    whole[index,1] <- rep(x$specs$model$params$probs[1,index_orig], x$specs$n.groups)
+    if (any(x$specs$model$params$probs[1,index_orig] %in% rowNms)) {
+      tmp <- numeric(length = length(index_orig)*x$specs$n.groups)
+      if (all(x$specs$model$params$probs[1,index_orig] %in% rowNms)) {
+        
+        nms <- as.character(x$specs$model$params$probs[1,index_orig])
+        ind_nms <- sapply(X = nms, FUN = function(i) {which(names(x$specs$model$params$probs) %in% i)})
+        ind_mu_probs <- sapply(X = ind_nms, FUN = function(i) sum(is.na(x$specs$model$params$probs[1, 1:i])))
+        if (x$specs$n.groups == 1) {
+          tmp <- x$diags$mu_probs[ind_mu_probs,3]
+        } else {
+          ind_mu_probs_g <- ind_mu_probs; for ( i in 1:(x$specs$n.groups-1) ) {ind_mu_probs_g <- c(ind_mu_probs_g, ind_mu_probs_g+length(x$diags$mu_probs[,3])/x$specs$n.groups)}
+          tmp <- x$diags$mu_probs[ind_mu_probs_g,3]
+        }
+        
+      } else {
+        ind_cnst <- which(!x$specs$model$params$probs[1,index_orig] %in% rowNms)
+        ind_eql <- which(x$specs$model$params$probs[1,index_orig] %in% rowNms)
+        nms <- as.character(x$specs$model$params$probs[1,index_orig[ind_eql]])
+        ind_nms <- sapply(X = nms, FUN = function(i) {which(names(x$specs$model$params$probs) %in% i)})
+        ind_mu_probs <- sapply(X = ind_nms, FUN = function(i) sum(is.na(x$specs$model$params$probs[1, 1:i])))
+        if (x$specs$n.groups == 1) {
+          tmp[ind_cnst] <- x$specs$model$params$probs[1,index_orig[ind_cnst]]
+          tmp[ind_eql] <- x$diags$mu_probs[ind_mu_probs,3]
+        } else {
+          ind_cnst_g <- ind_cnst; for ( i in 1:(x$specs$n.groups-1) ) {ind_cnst_g <- c(ind_cnst_g, ind_cnst_g+length(index_orig))}
+          ind_eql_g <- ind_eql; for ( i in 1:(x$specs$n.groups-1) ) {ind_eql_g <- c(ind_eql_g, ind_eql_g+length(index_orig))}
+          tmp[ind_cnst_g] <- x$specs$model$params$probs[1,index_orig[ind_cnst]]
+          ind_mu_probs_g <- ind_mu_probs; for ( i in 1:(x$specs$n.groups-1) ) {ind_mu_probs_g <- c(ind_mu_probs_g, ind_mu_probs_g+length(x$diags$mu_probs[,3])/x$specs$n.groups)}
+          tmp[ind_eql_g] <- x$diags$mu_probs[ind_mu_probs_g,3]
+        }
+        
+      }
+      whole[index,1] <- tmp
+    } else whole[index,1] <- rep(as.numeric(x$specs$model$params$probs[1,index_orig]), x$specs$n.groups)
   }
+  
   index <- which(is.na(x$specs$model$params$taus[1,]))
   if (x$specs$n.groups>1) for (i in 1:(x$specs$n.groups-1)) {index <- c(index, index+length(rowNms))}
   whole[index,2] <- x$diags$mu_tau_minus[,3]
+  if (length(which(!is.na(x$specs$model$params$taus[1,])))>0) {
+    index <- which(!is.na(x$specs$model$params$taus[1,]))
+    index_orig <- index
+    if (x$specs$n.groups>1) for (i in 1:(x$specs$n.groups-1)) {index <- c(index, index+length(rowNms))}
+    if (any(x$specs$model$params$taus[1,index_orig] %in% rowNms)) {
+      tmp <- numeric(length = length(index_orig)*x$specs$n.groups)
+      if (all(x$specs$model$params$taus[1,index_orig] %in% rowNms)) {
+        
+        nms <- as.character(x$specs$model$params$taus[1,index_orig])
+        ind_nms <- sapply(X = nms, FUN = function(i) {which(rowNms %in% i)})
+        ind_mu_tau_minus <- sapply(X = ind_nms, FUN = function(i) sum(is.na(x$specs$model$params$taus[1, 1:i])))
+        if (x$specs$n.groups == 1) {
+          tmp <- x$diags$mu_tau_minus[ind_mu_tau_minus,3]
+        } else {
+          ind_mu_tau_minus_g <- ind_mu_tau_minus; for ( i in 1:(x$specs$n.groups-1) ) {ind_mu_tau_minus_g <- c(ind_mu_tau_minus_g, ind_mu_tau_minus_g+length(x$diags$mu_tau_minus[,3])/x$specs$n.groups)}
+          tmp <- x$diags$mu_tau_minus[ind_mu_tau_minus_g,3]
+        }
+        
+      } else {
+        ind_zero <- which(!x$specs$model$params$taus[1,index_orig] %in% rowNms)
+        ind_eql <- which(x$specs$model$params$taus[1,index_orig] %in% rowNms)
+        nms <- as.character(x$specs$model$params$taus[1,index_orig[ind_eql]])
+        ind_nms <- sapply(X = nms, FUN = function(i) {which(rowNms %in% i)})
+        ind_mu_tau_minus <- sapply(X = ind_nms, FUN = function(i) sum(is.na(x$specs$model$params$taus[1, 1:i])))
+        if (x$specs$n.groups == 1) {
+          tmp[ind_zero] <- x$specs$model$params$taus[1,index_orig[ind_zero]]
+          tmp[ind_eql] <- x$diags$mu_tau_minus[ind_mu_tau_minus,3]
+        } else {
+          ind_zero_g <- ind_zero; for ( i in 1:(x$specs$n.groups-1) ) {ind_zero_g <- c(ind_zero_g, ind_zero_g+length(index_orig))}
+          ind_eql_g <- ind_eql; for ( i in 1:(x$specs$n.groups-1) ) {ind_eql_g <- c(ind_eql_g, ind_eql_g+length(index_orig))}
+          tmp[ind_zero_g] <- x$specs$model$params$taus[1,index_orig[ind_zero]]
+          ind_mu_tau_minus_g <- ind_mu_tau_minus; for ( i in 1:(x$specs$n.groups-1) ) {ind_mu_tau_minus_g <- c(ind_mu_tau_minus_g, ind_mu_tau_minus_g+length(x$diags$mu_tau_minus[,3])/x$specs$n.groups)}
+          tmp[ind_eql_g] <- x$diags$mu_tau_minus[ind_mu_tau_minus_g,3]
+        }
+        
+      }
+      whole[index,2] <- tmp
+    } else whole[index,2] <- rep(as.numeric(x$specs$model$params$taus[1,index_orig]), x$specs$n.groups)
+  }
+  
   index <- which(is.na(x$specs$model$params$taus[2,]))
   if (x$specs$n.groups>1) for (i in 1:(x$specs$n.groups-1)) {index <- c(index, index+length(rowNms))}
   whole[index,3] <- x$diags$mu_tau_plus[,3]
+  if (length(which(!is.na(x$specs$model$params$taus[2,])))>0) {
+    index <- which(!is.na(x$specs$model$params$taus[2,]))
+    index_orig <- index
+    if (x$specs$n.groups>1) for (i in 1:(x$specs$n.groups-1)) {index <- c(index, index+length(rowNms))}
+    if (any(x$specs$model$params$taus[2,index_orig] %in% rowNms)) {
+      tmp <- numeric(length = length(index_orig)*x$specs$n.groups)
+      if (all(x$specs$model$params$taus[2,index_orig] %in% rowNms)) {
+        
+        nms <- as.character(x$specs$model$params$taus[2,index_orig])
+        ind_nms <- sapply(X = nms, FUN = function(i) {which(rowNms %in% i)})
+        ind_mu_tau_plus <- sapply(X = ind_nms, FUN = function(i) sum(is.na(x$specs$model$params$taus[2, 1:i])))
+        if (x$specs$n.groups == 1) {
+          tmp <- x$diags$mu_tau_plus[ind_mu_tau_plus,3]
+        } else {
+          ind_mu_tau_plus_g <- ind_mu_tau_plus; for ( i in 1:(x$specs$n.groups-1) ) {ind_mu_tau_plus_g <- c(ind_mu_tau_plus_g, ind_mu_tau_plus_g+length(x$diags$mu_tau_plus[,3])/x$specs$n.groups)}
+          tmp <- x$diags$mu_tau_plus[ind_mu_tau_plus_g,3]
+        }
+        
+      } else {
+        ind_zero <- which(!x$specs$model$params$taus[2,index_orig] %in% rowNms)
+        ind_eql <- which(x$specs$model$params$taus[2,index_orig] %in% rowNms)
+        nms <- as.character(x$specs$model$params$taus[2,index_orig[ind_eql]])
+        ind_nms <- sapply(X = nms, FUN = function(i) {which(rowNms %in% i)})
+        ind_mu_tau_plus <- sapply(X = ind_nms, FUN = function(i) sum(is.na(x$specs$model$params$taus[2, 1:i])))
+        if (x$specs$n.groups == 1) {
+          tmp[ind_zero] <- x$specs$model$params$taus[2,index_orig[ind_zero]]
+          tmp[ind_eql] <- x$diags$mu_tau_plus[ind_mu_tau_plus,3]
+        } else {
+          ind_zero_g <- ind_zero; for ( i in 1:(x$specs$n.groups-1) ) {ind_zero_g <- c(ind_zero_g, ind_zero_g+length(index_orig))}
+          ind_eql_g <- ind_eql; for ( i in 1:(x$specs$n.groups-1) ) {ind_eql_g <- c(ind_eql_g, ind_eql_g+length(index_orig))}
+          tmp[ind_zero_g] <- x$specs$model$params$taus[2,index_orig[ind_zero]]
+          ind_mu_tau_plus_g <- ind_mu_tau_plus; for ( i in 1:(x$specs$n.groups-1) ) {ind_mu_tau_plus_g <- c(ind_mu_tau_plus_g, ind_mu_tau_plus_g+length(x$diags$mu_tau_plus[,3])/x$specs$n.groups)}
+          tmp[ind_eql_g] <- x$diags$mu_tau_plus[ind_mu_tau_plus_g,3]
+        }
+        
+      }
+      whole[index,3] <- tmp
+    } else whole[index,3] <- rep(as.numeric(x$specs$model$params$taus[2,index_orig]), x$specs$n.groups)
+  }
+  
   cat("Process-related parameters:\n")
   print(whole)
   cat("\n* NOTE 1: Process completion times in ms.")
