@@ -333,9 +333,9 @@ sim_rtmpt_data <- function(model,
   Nminus <- sum(is.na(model$params$taus[1,]))
   Nplus <- sum(is.na(model$params$taus[2,]))
   Nsubj <- n.subj
-  Nresp <- length(unique(model$responses$RESP))
+  Nresp <- length(unique(model$responses$MAP))
   NTrials <- n.trials
-  Executions <- model$responses$RESP+1
+  Executions <- model$responses$MAP+1
   some_const <- any(!is.na(model$params$probs[1,]))
   PositionProb <- ifelse(some_const, which(!is.na(model$params$probs[1,])), 0)
   ConstProb <- ifelse(some_const, model$params$probs[1, PositionProb], 0)
